==> haskell-loop-0.3.0-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-loop.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: loop
version: 0.3.0
id: loop-0.3.0-BJ2THzC3CjL5MGE8KLpt6z
key: loop-0.3.0-BJ2THzC3CjL5MGE8KLpt6z
license: MIT
copyright: 2014 Niklas Hambüchen <mail@nh2.me>
maintainer: Niklas Hambüchen <mail@nh2.me>
author: Niklas Hambüchen <mail@nh2.me>
stability: experimental
homepage: https://github.com/nh2/loop
synopsis: Fast loops (for when GHC can'\''t optimize forM_)
description:
    This package provides a convenient and fast alternative to the common
    `forM_ [1..n]` idiom, which in many cases GHC cannot fuse to efficient
    code.
    .
    See <https://ghc.haskell.org/trac/ghc/ticket/8763>.
category: Control
abi: 5279ede0b71a82e34f71d129478eabc0
exposed: True
exposed-modules:
    Control.Loop Control.Loop.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/loop-0.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/loop-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/loop-0.3.0
hs-libraries: HSloop-0.3.0-BJ2THzC3CjL5MGE8KLpt6z
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-loop/html/loop.haddock
haddock-html: /usr/share/doc/haskell-loop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-loop-0.3.0-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-loop.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: loop
version: 0.3.0
id: loop-0.3.0-6gPGwAdiNhIH8gA5YRIS8n
key: loop-0.3.0-6gPGwAdiNhIH8gA5YRIS8n
license: MIT
copyright: 2014 Niklas Hambüchen <mail@nh2.me>
maintainer: Niklas Hambüchen <mail@nh2.me>
author: Niklas Hambüchen <mail@nh2.me>
stability: experimental
homepage: https://github.com/nh2/loop
synopsis: Fast loops (for when GHC can'\''t optimize forM_)
description:
    This package provides a convenient and fast alternative to the common
    `forM_ [1..n]` idiom, which in many cases GHC cannot fuse to efficient
    code.
    .
    See <https://ghc.haskell.org/trac/ghc/ticket/8763>.
category: Control
abi: 023b85d36fe9ca70277b4c5613a68ef0
exposed: True
exposed-modules:
    Control.Loop Control.Loop.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/loop-0.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/loop-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/loop-0.3.0
hs-libraries: HSloop-0.3.0-6gPGwAdiNhIH8gA5YRIS8n
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-loop/html/loop.haddock
haddock-html: /usr/share/doc/haskell-loop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
